@@ -1,18 +1,23 @@
+# This code is licensed under the New BSD License
+# 2009, Alexander Artemenko <svetlyak.40wt@gmail.com>
+# For other contacts, visit http://aartemenko.com
+
 from elixir import *
 from utils import get_or_create
 from pdb import set_trace
 
 class Task(Entity):
-    title = Field(Unicode(40))
+    title = Field(Unicode(40), required = True)
     note = Field(UnicodeText)
     tags = ManyToMany('Tag')
-    priority = Field(Float)
-    done = Field(Boolean, default = False)
+    priority = Field(Float, default = 1, required = True)
+    done = Field(Boolean, default = False, required = True)
 
     using_options(tablename='tasks', order_by='-priority')
 
-    def __str__(self):
-        return u'"%s" / %s (%s)' % (self.title, self.priority, ', '.join(map(unicode, self.tags)))
+    def __unicode__(self):
+        return u'"%s" / %s %s (%s)' % (
+            self.title, self.priority, self.done and 'CLOSED' or 'OPEN', ', '.join(map(unicode, self.tags)))
 
     def __repr__(self):
         return u'<Task "%s" with tags %s>' % (self.title, ', '.join(map(unicode, self.tags)))
@@ -21,12 +26,12 @@ class Task(Entity):
         self.tags = [get_or_create(Tag, title = tag) for tag in tags]
 
 class Tag(Entity):
-    title = Field(Unicode(40), unique = True)
+    title = Field(Unicode(40), required = True, unique = True)
     tasks = ManyToMany('Task')
 
     using_options(tablename='tags', order_by='title')
 
-    def __str__(self):
+    def __unicode__(self):
         return self.title
 
     def __repr__(self):
